@@ -13,6 +13,14 @@ my $functions = {
   encode_json  => sub { my $value = shift; return ( encode_json($value) ); },
   encode_bool  => sub { my $value = shift; return ( defined($value) ? ( $value ? 'true' : 'false' ) : $value ); },
   concat_comma => sub { my $value = shift; return ( join( ',', @{$value} ) ); },
+  encode_bulk  => sub {
+    my $value = shift;
+    my $bulk  = [];
+    foreach my $item ( @{$value} ) {
+      push( @{$bulk}, encode_json($item) );
+    }
+    return ( join( "\n", @{$bulk} ) . "\n" );
+  },
 };
 
 sub _generate_params( $self, $instance ) {
@@ -26,7 +34,7 @@ sub _generate_params( $self, $instance ) {
     # TODO: This might conflice with attributes starting with _.
     #       ie. _source, _source_includes, _source_excludes
     #       Since these are optional we dont care about them for now.
-    next if ( $param =~ m/^_/ );
+    next if ( $param =~ m/^_base/ );
     my $desc = $instance->meta->{attributes}->{$param}->description;
     my $enc  = $desc->{encode_func} // 'as_is';
     my $req  = $desc->{required};
@@ -36,6 +44,11 @@ sub _generate_params( $self, $instance ) {
     # Skipp all other body params if forced_body is already set
     next if ( $forced && ( $type eq 'body' ) );
 
+    # If forced_body is set by any attribute, we will only use this body param
+    if ( $value && $fb ) {
+      $forced = 1;
+    }
+
     if ($req) {
       my $caller = ( caller(4) )[3];
 
@@ -58,8 +71,6 @@ sub _generate_params( $self, $instance ) {
 
   }
 
-  #print Dumper $parsed;
-
   return ($parsed);
 }
 
